@@ -12,9 +12,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
-   02110-1301, USA.  */
+   along with this program; if not, see
+   <https://www.gnu.org/licenses/gpl-3.0.html>.  */
 
 #ifndef SYSTEM_H_
 #define SYSTEM_H_
@@ -118,7 +117,7 @@
 #include <stdarg.h>
 
 #include "xalloc.h"
-#include "error.h"
+#include <error.h>
 
 /* Cardinality of a static array. */
 
