@@ -12,9 +12,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
-   02110-1301, USA.  */
+   along with this program; if not, see
+   <https://www.gnu.org/licenses/gpl-3.0.html>.  */
 
 /* FIXME: There is a case where the behavior is probably wrong: mixed
    string/stream buffers.  It may happen that the last char of the
